revmc_exit

Function revmc_exit 

pub unsafe extern "C" fn revmc_exit(ecx: *const EvmContext<'_>) -> !
Exit trampoline: loads ecx.exit_result, restores the saved RSP, pops callee-saved registers and returns to the caller of revmc_entry.

Safety

Must only be called from a builtin that was invoked through revmc_entry.