EvmContext

Struct EvmContext 

pub struct EvmContext<'a> {
Show 15 fields pub memory: &'a mut SharedMemory, pub input: &'a mut InputsImpl, pub gas: Gas, pub host: &'a mut dyn Host, pub next_action: &'a mut Option<InterpreterAction>, pub return_data: &'a [u8], pub is_static: bool, pub spec_id: SpecId, pub bytecode: *const [u8], pub calldatasize: usize, pub exit_result: InstructionResult, pub exit_sp: *mut u8, pub gas_params: GasParams, pub mem_base: *mut u8, pub mem_len: usize, /* private fields */
}
The EVM bytecode compiler runtime context.

This is a simple wrapper around the interpreter’s resources, allowing the compiled function to access the memory, input, gas, host, and other resources.

Safety

This struct uses #[repr(C)] to ensure a stable field layout since the JIT compiler generates code that accesses fields by offset using offset_of!.

Fields

memory: &'a mut SharedMemory

The memory.

input: &'a mut InputsImpl

Input information (target address, caller, input data, call value).

gas: Gas

The gas.

host: &'a mut dyn Host

The host.

next_action: &'a mut Option<InterpreterAction>

The return action.

return_data: &'a [u8]

The return data.

is_static: bool

Whether the context is static.

spec_id: SpecId

The spec ID for the current execution.

bytecode: *const [u8]

The contract bytecode, for CODECOPY at runtime.

calldatasize: usize

The size of the call input data, cached for CALLDATASIZE.

exit_result: InstructionResult

The result set by a builtin before exiting via revmc_exit.

exit_sp: *mut u8

Saved RSP from the entry trampoline, used by revmc_exit to unwind.

gas_params: GasParams

Cached gas parameters from the host.

mem_base: *mut u8

Cached base pointer for the current memory context. Points to memory[checkpoint..], i.e. the start of the current context’s memory. Refreshed after any memory resize.

mem_len: usize

Cached length of the current memory context in bytes. Refreshed after any memory resize.

Implementations

Source

impl<'a> EvmContext<'a>

pub fn from_interpreter( interpreter: &'a mut Interpreter, host: &'a mut dyn Host, ) -> Self

Creates a new context from an interpreter.

pub fn from_interpreter_with_stack<'b: 'a>( interpreter: &'a mut Interpreter, host: &'b mut dyn Host, ) -> (Self, &'a mut EvmStack, &'a mut usize)

Creates a new context from an interpreter.

pub fn refresh_memory_cache(&mut self)

Refreshes the cached memory base pointer and length from SharedMemory.

Must be called after any operation that may resize memory.